@@ -1,7 +1,7 @@
 package MooseX::Getopt::Usage::Formatter;
 
 use 5.010;
-our $VERSION = '0.21_01';
+our $VERSION = '0.09';
 
 use Moose;
 #use MooseX::StrictConstructor;
@@ -64,15 +64,16 @@ has pod_file => (
 
 sub _build_pod_file {
     my $self = shift;
-
-    # Script file, may have inline pod docs
-    my $file = "$FindBin::Bin/$FindBin::Script";
-    return $file if -f $file && contains_pod($file);
-
-    # Use the pod docs from the class
     my $gclass = $self->getopt_class;
-    return pod_where( {-inc => 1}, $gclass ) if is_loaded($gclass);
-
+    if ( is_loaded($gclass) ) {
+        return pod_where( {-inc => 1}, $gclass );
+    }
+    else {
+        # Class doesn't seem to be loaded (used) so try the script file. E.g. a
+        # class definition and main pkg runner all in one file.
+        my $file = "$FindBin::Bin/$FindBin::Script";
+        return $file if -f $file && contains_pod($file);
+    }
     return undef;
 }
 
@@ -121,23 +122,6 @@ sub _build_format {
     return $selected ? $selected : "%c [OPTIONS]";
 }
 
-has width => (
-    is      => "rw",
-    isa     => "Int",
-    lazy_build => 1,
-);
-
-sub _build_width {
-    my $self = shift;
-    my $w = 72;
-    if (-t STDOUT) {
-        my ($tw) = GetTerminalSize();
-        $w = $tw -1 if defined $tw;
-    }
-    return $w;
-}
-
-
 has attr_sort => (
     is      => "rw",
     isa     => "CodeRef",
@@ -188,18 +172,20 @@ sub _set_color_handling {
     my $mode = shift;
 
     $ENV{ANSI_COLORS_DISABLED} = defined $ENV{ANSI_COLORS_DISABLED} ? 1 : undef;
-    if ($mode eq 'auto') {
-        if ( not defined $ENV{ANSI_COLORS_DISABLED} ) {
-            $ENV{ANSI_COLORS_DISABLED} = -t STDOUT ? undef : 1;
+    given ($mode) {
+        when ('auto') {
+            if ( not defined $ENV{ANSI_COLORS_DISABLED} ) {
+                $ENV{ANSI_COLORS_DISABLED} = -t STDOUT ? undef : 1;
+            }
         }
+        when ('always') {
+            $ENV{ANSI_COLORS_DISABLED} = undef;
+        }
+        when ('never') {
+            $ENV{ANSI_COLORS_DISABLED} = 1;
+        }
+        # 'env' is done in the env set line above
     }
-    elsif ($mode eq 'always') {
-        $ENV{ANSI_COLORS_DISABLED} = undef;
-    }
-    elsif ($mode eq 'never') {
-        $ENV{ANSI_COLORS_DISABLED} = 1;
-    }
-    # 'env' is done in the env set line above
 }
 
 sub usage {
@@ -218,7 +204,6 @@ sub usage {
         options_style => 'text',
     );
     my $parser = MooseX::Getopt::Usage::Pod::Text->new(
-        width    => $self->width,
         headings => $self->headings
     );
     my $out;
@@ -305,20 +290,14 @@ sub _get_pod {
     return $out;
 }
 
-# Return list of class attributes that are options.
-sub _getopt_attrs {
-    my $self   = shift;
-    my $gclass = $self->getopt_class;
-    my $attr_sort = $self->attr_sort;
-    return sort { $attr_sort->($a, $b) } $gclass->_compute_getopt_attrs;
-}
-
 # Generate POD version of the options from the meta info.
 sub _options_pod {
     my $self   = shift;
+    my $gclass = $self->getopt_class;
 
-    my @attrs = $self->_getopt_attrs;
     my $options_pod = "";
+    #my @attrs = sort { $attr_sort->($a, $b) } $self->_compute_getopt_attrs;
+    my @attrs = $gclass->_compute_getopt_attrs;
     $options_pod .= "=over 4\n\n";
     foreach my $attr (@attrs) {
         my $label = $self->_attr_label($attr);
@@ -333,9 +312,12 @@ sub _options_pod {
 sub _options_text {
     my $self = shift;
     my $args = { @_ };
-    my $colours = $self->colours;
 
-    my @attrs = $self->_getopt_attrs;
+    my $gclass    = $self->getopt_class;
+    my $colours   = $self->colours;
+    my $attr_sort = $self->attr_sort;
+
+    my @attrs = sort { $attr_sort->($a, $b) } $gclass->_compute_getopt_attrs;
     my $max_len = 0;
     my (@req_attrs, @opt_attrs);
     foreach (@attrs) {
@@ -374,9 +356,6 @@ sub _parse_format {
     my $colours = $self->colours;
 
     $fmt =~ s/%c/colored $colours->{command}, prog_name()/ieg;
-    $fmt =~ s/%a/$self->_format_opt_line('a')/ieg;
-    $fmt =~ s/%r/$self->_format_opt_line('r')/ieg;
-    $fmt =~ s/%o/$self->_format_opt_line('o')/ieg;
     $fmt =~ s/%%/%/g;
     # TODO - Be good to have a include that generates a list of the opts
     #        %r - required  %a - all  %o - options
@@ -385,44 +364,6 @@ sub _parse_format {
     return $fmt;
 }
 
-sub _format_opt_line {
-    my $self = shift;
-    my $group = shift;
-
-    my @attrs;
-    if ( !$group || $group eq "a" ) {
-        @attrs = $self->_getopt_attrs;
-    }
-    elsif ( $group eq "r" ) {
-        @attrs = grep {
-            $_->is_required && !$_->has_default && !$_->has_builder
-        } $self->_getopt_attrs;
-    }
-    elsif ( $group eq "o" ) {
-        @attrs = grep {
-            !($_->is_required && !$_->has_default && !$_->has_builder)
-        } $self->_getopt_attrs;
-    }
-    else {
-        confess "Unknown grouping: $group";
-    }
-
-    my @out;
-    foreach my $attr (@attrs) {
-        my $opt = "";
-        my $label = $self->_attr_label($attr);
-        $opt .= "$label";
-        if ( not $attr->type_constraint->is_a_type_of("Bool") ) {
-            $opt .= "=".uc($attr->name)
-        }
-        if (!$attr->is_required || $attr->has_default || $attr->has_builder) {
-            $opt = "[$opt]";
-        }
-        push @out, $opt;
-    }
-    return join(" ", @out);;
-}
-
 # Return the full label, including aliases and dashes, for the passed attribute
 sub _attr_label {
     my $self   = shift;
@@ -445,7 +386,8 @@ sub _attr_str {
     my $indent  = $args{indent} || 0;
     my $colours = $self->colours;
 
-    local $Text::Wrap::columns  = $self->width;
+    my ($w) = GetTerminalSize;
+    local $Text::Wrap::columns = $w -1 || 72;
     local $Text::Wrap::unexpand = $self->unexpand;
     local $Text::Wrap::tabstop  = $self->tabstop;
 
@@ -453,11 +395,11 @@ sub _attr_str {
 
     my $docs  = "";
     my $pad   = $max_len - length($label);
-    my $def   = $attr->has_default ? $attr->default : undef;
+    my $def   = $attr->has_default ? $attr->default : "";
     (my $type = $attr->type_constraint) =~ s/(\w+::)*//g;
     $docs .= colored($colours->{type}, "$type. ") if $type;
     $docs .= colored($colours->{default_value}, "Default=$def").". "
-        if defined $def && ! ref $def;
+        if $def && ! ref $def;
     $docs  .= $attr->documentation || "";
 
     my $col1 = (" " x $indent).$label;
@@ -474,7 +416,7 @@ sub _colourise {
     my $colours = $self->colours;
 
     my $str = ref $out ? $out : \$out;
-    $$str =~ s/(^|\s|\[)(--?[\w?]+)/"$1".colored $colours->{flag},"$2"/ge;
+    $$str =~ s/((?:^|\s)--?[\w?]+)/colored $colours->{flag}, "$1"/ge;
     return ref $out ? $out : $$str;
 }
 
